#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discovery_device_range_v1_info
short_description: Information module for Discovery Device Range V1
description:
- Get all Discovery Device Range V1.
- >
   Returns the network devices discovered for the given discovery and for the given range. The maximum number of
   records that can be retrieved is 500. Discovery ID can be obtained using the "Get Discoveries by range" API.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
    - Id path parameter. Discovery ID.
    type: str
  startIndex:
    description:
    - StartIndex path parameter. Starting index for the records.
    type: int
  recordsToReturn:
    description:
    - RecordsToReturn path parameter. Number of records to fetch from the start index.
    type: int
  taskId:
    description:
    - TaskId query parameter.
    type: str
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Discovery GetDiscoveredDevicesByRangeV1
  description: Complete reference of the GetDiscoveredDevicesByRangeV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-discovered-devices-by-range
notes:
  - SDK Method used are
    discovery.Discovery.get_discovered_devices_by_range_v1,

  - Paths used are
    get /dna/intent/api/v1/discovery/{id}/network-device/{startIndex}/{recordsToReturn},

"""

EXAMPLES = r"""
- name: Get all Discovery Device Range V1
  cisco.dnac.discovery_device_range_v1_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
    id: string
    startIndex: 0
    recordsToReturn: 0
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "anchorWlcForAp": "string",
          "authModelId": "string",
          "avgUpdateFrequency": 0,
          "bootDateTime": "string",
          "cliStatus": "string",
          "duplicateDeviceId": "string",
          "errorCode": "string",
          "errorDescription": "string",
          "family": "string",
          "hostname": "string",
          "httpStatus": "string",
          "id": "string",
          "imageName": "string",
          "ingressQueueConfig": "string",
          "interfaceCount": "string",
          "inventoryCollectionStatus": "string",
          "inventoryReachabilityStatus": "string",
          "lastUpdated": "string",
          "lineCardCount": "string",
          "lineCardId": "string",
          "location": "string",
          "locationName": "string",
          "macAddress": "string",
          "managementIpAddress": "string",
          "memorySize": "string",
          "netconfStatus": "string",
          "numUpdates": 0,
          "pingStatus": "string",
          "platformId": "string",
          "portRange": "string",
          "qosStatus": "string",
          "reachabilityFailureReason": "string",
          "reachabilityStatus": "string",
          "role": "string",
          "roleSource": "string",
          "serialNumber": "string",
          "snmpContact": "string",
          "snmpLocation": "string",
          "snmpStatus": "string",
          "softwareVersion": "string",
          "tag": "string",
          "tagCount": 0,
          "type": "string",
          "upTime": "string",
          "vendor": "string",
          "wlcApDeviceStatus": "string"
        }
      ],
      "version": "string"
    }
"""



# (c) 2018 Red Hat Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

DOCUMENTATION = """
---
author: Ansible Networking Team (@rcarrillocruz)
name: checkpoint
short_description: HttpApi Plugin for Checkpoint devices
description:
  - This HttpApi plugin provides methods to connect to Checkpoint
    devices over a HTTP(S)-based api.
version_added: "2.8.0"
options:
  domain:
    type: str
    description:
      - Specifies the domain of the Check Point device
    vars:
      - name: ansible_checkpoint_domain
  api_key:
    type: str
    description:
      - Login with api-key instead of user & password
    vars:
      - name: ansible_api_key
  cloud_mgmt_id:
    type: str
    description:
      - The Cloud Management ID
    vars:
      - name: ansible_cloud_mgmt_id
  target:
    type: str
    description:
      - target gateway
    vars:
      - name: ansible_checkpoint_target
"""

import json

from ansible.module_utils.basic import to_text
from ansible.errors import AnsibleConnectionFailure
from ansible.module_utils.six.moves.urllib.error import HTTPError
from ansible.plugins.httpapi import HttpApiBase
from ansible.module_utils.connection import ConnectionError

BASE_HEADERS = {
    "Content-Type": "application/json",
    "User-Agent": "Ansible",
}


class HttpApi(HttpApiBase):
    def login(self, username, password):
        payload = {}
        cp_domain = self.get_option("domain")
        cp_api_key = self.get_option("api_key")
        if cp_domain:
            payload["domain"] = cp_domain
        if username and password and not cp_api_key:
            payload["user"] = username
            payload["password"] = password
        elif cp_api_key and not username and not password:
            payload["api-key"] = cp_api_key
        else:
            raise AnsibleConnectionFailure(
                "[Username and password] or api_key are required for login"
            )
        url = "/web_api/login"
        response, response_data = self.send_request(url, payload)
        if response != 200:
            raise ConnectionError("Login to server failed: %s" % response_data)
        try:
            self.connection._auth = {"X-chkp-sid": response_data["sid"]}
        except KeyError:
            raise ConnectionError(
                "Server returned response without token info during connection authentication: %s"
                % response
            )
        # Case of read-only
        if "uid" in response_data.keys():
            self.connection._session_uid = response_data["uid"]

    def logout(self):
        url = "/web_api/logout"

        response, dummy = self.send_request(url, None)

    def get_session_uid(self):
        return self.connection._session_uid

    def send_request(self, path, body_params):
        cp_cloud_mgmt_id = self.get_option("cloud_mgmt_id")
        if cp_cloud_mgmt_id:
            path = "/" + cp_cloud_mgmt_id + path
        # we only replace gaia_ip/ with web_api/gaia-api/ if target is set and path contains gaia_ip/
        if 'gaia_api/' in path and self.get_option("target"):
            path = path.replace("gaia_api/", "web_api/gaia-api/")
            body_params['target'] = self.get_option("target")
        data = json.dumps(body_params) if body_params else '{}'
        try:
            self._display_request()
            response, response_data = self.connection.send(
                path, data, method="POST", headers=BASE_HEADERS
            )
            value = self._get_response_value(response_data)

            return response.getcode(), self._response_to_json(value)
        except AnsibleConnectionFailure as e:
            return 404, e.message
        except HTTPError as e:
            error = json.loads(e.read())
            return e.code, error

    def _display_request(self):
        self.connection.queue_message(
            "vvvv", "Web Services: %s %s" % ("POST", self.connection._url)
        )

    def _get_response_value(self, response_data):
        return to_text(response_data.getvalue())

    def _response_to_json(self, response_text):
        try:
            return json.loads(response_text) if response_text else {}
        # JSONDecodeError only available on Python 3.5+
        except ValueError:
            raise ConnectionError("Invalid JSON response: %s" % response_text)



# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function


__metaclass__ = type

#############################################
#                WARNING                    #
#############################################
#
# This file is auto generated by the
# cli_rm_builder.
#
# Manually editing this file is not advised.
#
# To update the argspec make the desired changes
# in the module docstring and re-run
# cli_rm_builder.
#
#############################################

"""
The arg spec for the iosxr_bgp_neighbor_address_family module
"""


class Bgp_neighbor_address_familyArgs(object):  # pylint: disable=R0903
    """The arg spec for the iosxr_bgp_neighbor_address_family module"""

    def __init__(self, **kwargs):
        pass

    argument_spec = {
        "config": {
            "type": "dict",
            "options": {
                "as_number": {"type": "str"},
                "neighbors": {
                    "type": "list",
                    "elements": "dict",
                    "options": {
                        "neighbor_address": {"type": "str", "required": True},
                        "address_family": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "afi": {
                                    "type": "str",
                                    "choices": [
                                        "ipv4",
                                        "ipv6",
                                        "l2vpn",
                                        "link-state",
                                        "vpnv4",
                                        "vpnv6",
                                    ],
                                },
                                "safi": {
                                    "type": "str",
                                    "choices": [
                                        "flowspec",
                                        "mdt",
                                        "multicast",
                                        "mvpn",
                                        "rt-filter",
                                        "tunnel",
                                        "unicast",
                                        "labeled-unicast",
                                    ],
                                },
                                "aigp": {
                                    "type": "dict",
                                    "options": {
                                        "disable": {"type": "bool"},
                                        "set": {"type": "bool"},
                                        "send_cost_community_disable": {"type": "bool"},
                                        "send_med": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "disable": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "allowas_in": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "value"],
                                    ],
                                    "options": {"value": {"type": "int"}, "set": {"type": "bool"}},
                                },
                                "as_override": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "bestpath_origin_as_allow_invalid": {"type": "bool"},
                                "capability_orf_prefix": {
                                    "type": "str",
                                    "choices": ["both", "send", "none", "receive"],
                                },
                                "default_originate": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "route_policy", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "route_policy": {"type": "str"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "long_lived_graceful_restart": {
                                    "type": "dict",
                                    "options": {
                                        "capable": {"type": "bool"},
                                        "stale_time": {
                                            "type": "dict",
                                            "options": {
                                                "send": {"type": "int"},
                                                "accept": {"type": "int"},
                                            },
                                        },
                                    },
                                },
                                "maximum_prefix": {
                                    "type": "dict",
                                    "options": {
                                        "max_limit": {"type": "int"},
                                        "threshold_value": {"type": "int"},
                                        "restart": {"type": "int"},
                                        "warning_only": {"type": "bool"},
                                        "discard_extra_paths": {"type": "bool"},
                                    },
                                },
                                "multipath": {"type": "bool"},
                                "next_hop_self": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "next_hop_unchanged": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                        "multipath": {"type": "bool"},
                                    },
                                },
                                "optimal_route_reflection_group_name": {"type": "str"},
                                "orf_route_policy": {"type": "str"},
                                "origin_as": {
                                    "type": "dict",
                                    "options": {
                                        "validation": {
                                            "type": "dict",
                                            "options": {"disable": {"type": "bool"}},
                                        },
                                    },
                                },
                                "remove_private_AS": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inbound": {"type": "bool"},
                                        "entire_aspath": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "route_policy": {
                                    "type": "dict",
                                    "options": {
                                        "inbound": {"type": "str"},
                                        "outbound": {"type": "str"},
                                    },
                                },
                                "route_reflector_client": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "send_community_ebgp": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "send_community_gshut_ebgp": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "send_extended_community_ebgp": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "inheritance_disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "inheritance_disable": {"type": "bool"},
                                    },
                                },
                                "send_multicast_attributes": {
                                    "type": "dict",
                                    "mutually_exclusive": [
                                        ["set", "disable"],
                                    ],
                                    "options": {
                                        "set": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                                "soft_reconfiguration": {
                                    "type": "dict",
                                    "options": {
                                        "inbound": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "always", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "always": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                                "weight": {"type": "int"},
                                "validation": {
                                    "type": "dict",
                                    "options": {
                                        "set": {"type": "bool"},
                                        "redirect": {"type": "bool"},
                                        "disable": {"type": "bool"},
                                    },
                                },
                            },
                        },
                    },
                },
                "vrfs": {
                    "type": "list",
                    "elements": "dict",
                    "options": {
                        "vrf": {"type": "str"},
                        "neighbors": {
                            "type": "list",
                            "elements": "dict",
                            "options": {
                                "neighbor_address": {"type": "str", "required": True},
                                "address_family": {
                                    "type": "list",
                                    "elements": "dict",
                                    "options": {
                                        "afi": {"type": "str", "choices": ["ipv4", "ipv6"]},
                                        "safi": {
                                            "type": "str",
                                            "choices": [
                                                "flowspec",
                                                "multicast",
                                                "mvpn",
                                                "unicast",
                                                "labeled-unicast",
                                            ],
                                        },
                                        "aigp": {
                                            "type": "dict",
                                            "options": {
                                                "disable": {"type": "bool"},
                                                "set": {"type": "bool"},
                                                "send_cost_community_disable": {"type": "bool"},
                                                "send_med": {
                                                    "type": "dict",
                                                    "mutually_exclusive": [
                                                        ["set", "disable"],
                                                    ],
                                                    "options": {
                                                        "set": {"type": "bool"},
                                                        "disable": {"type": "bool"},
                                                    },
                                                },
                                            },
                                        },
                                        "allowas_in": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["value", "set"],
                                            ],
                                            "options": {
                                                "value": {"type": "int"},
                                                "set": {"type": "bool"},
                                            },
                                        },
                                        "as_override": {
                                            "type": "dict",
                                            "aliases": ["as_overrride"],
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "capability_orf_prefix": {
                                            "type": "str",
                                            "choices": ["both", "send", "none", "receive"],
                                        },
                                        "default_originate": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "route_policy", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "route_policy": {"type": "str"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "long_lived_graceful_restart": {
                                            "type": "dict",
                                            "options": {
                                                "capable": {"type": "bool"},
                                                "stale_time": {
                                                    "type": "dict",
                                                    "options": {
                                                        "send": {"type": "int"},
                                                        "accept": {"type": "int"},
                                                    },
                                                },
                                            },
                                        },
                                        "maximum_prefix": {
                                            "type": "dict",
                                            "options": {
                                                "max_limit": {"type": "int"},
                                                "threshold_value": {"type": "int"},
                                                "restart": {"type": "int"},
                                                "warning_only": {"type": "bool"},
                                                "discard_extra_paths": {"type": "bool"},
                                            },
                                        },
                                        "multipath": {"type": "bool"},
                                        "next_hop_self": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "next_hop_unchanged": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                                "multipath": {"type": "bool"},
                                            },
                                        },
                                        "optimal_route_reflection_group_name": {"type": "str"},
                                        "orf_route_policy": {"type": "str"},
                                        "remove_private_AS": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inbound": {"type": "bool"},
                                                "entire_aspath": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "route_policy": {
                                            "type": "dict",
                                            "options": {
                                                "inbound": {"type": "str"},
                                                "outbound": {"type": "str"},
                                            },
                                        },
                                        "route_reflector_client": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "send_community_ebgp": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "send_community_gshut_ebgp": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "send_extended_community_ebgp": {
                                            "type": "dict",
                                            "mutually_exclusive": [
                                                ["set", "inheritance_disable"],
                                            ],
                                            "options": {
                                                "set": {"type": "bool"},
                                                "inheritance_disable": {"type": "bool"},
                                            },
                                        },
                                        "soft_reconfiguration": {
                                            "type": "dict",
                                            "options": {
                                                "inbound": {
                                                    "type": "dict",
                                                    "mutually_exclusive": [
                                                        ["set", "always", "inheritance_disable"],
                                                    ],
                                                    "options": {
                                                        "set": {"type": "bool"},
                                                        "always": {"type": "bool"},
                                                        "inheritance_disable": {"type": "bool"},
                                                    },
                                                },
                                            },
                                        },
                                        "site_of_origin": {"type": "str"},
                                        "weight": {"type": "int"},
                                        "validation": {
                                            "type": "dict",
                                            "options": {
                                                "set": {"type": "bool"},
                                                "redirect": {"type": "bool"},
                                                "disable": {"type": "bool"},
                                            },
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        },
        "running_config": {"type": "str"},
        "state": {
            "type": "str",
            "choices": [
                "deleted",
                "merged",
                "overridden",
                "replaced",
                "gathered",
                "rendered",
                "parsed",
            ],
            "default": "merged",
        },
    }  # pylint: disable=C0301



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: templates_details_v2_info
short_description: Information module for Templates Details V2
description:
- Get all Templates Details V2.
- Get templates details.
version_added: '4.0.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
    - Id query parameter. Id of template to be searched.
    type: str
  name:
    description:
    - Name query parameter. Name of template to be searched.
    type: str
  projectId:
    description:
    - ProjectId query parameter. Filter template(s) based on project id.
    type: str
  projectName:
    description:
    - ProjectName query parameter. Filter template(s) based on project name.
    type: str
  softwareType:
    description:
    - SoftwareType query parameter. Filter template(s) based software type.
    type: str
  softwareVersion:
    description:
    - SoftwareVersion query parameter. Filter template(s) based softwareVersion.
    type: str
  productFamily:
    description:
    - ProductFamily query parameter. Filter template(s) based on device family.
    type: str
  productSeries:
    description:
    - ProductSeries query parameter. Filter template(s) based on device series.
    type: str
  productType:
    description:
    - ProductType query parameter. Filter template(s) based on device type.
    type: str
  filterConflictingTemplates:
    description:
    - FilterConflictingTemplates query parameter. Filter template(s) based on confliting templates.
    type: bool
  tags:
    description:
    - Tags query parameter. Filter template(s) based on tags.
    elements: str
    type: list
  unCommitted:
    description:
    - UnCommitted query parameter. Return uncommitted template.
    type: bool
  sortOrder:
    description:
    - SortOrder query parameter. Sort Order Ascending (asc) or Descending (dsc).
    type: str
  allTemplateAttributes:
    description:
    - AllTemplateAttributes query parameter. Return all template attributes.
    type: bool
  includeVersionDetails:
    description:
    - IncludeVersionDetails query parameter. Include template version details.
    type: bool
  offset:
    description:
    - Offset query parameter. Index of first result.
    type: int
  limit:
    description:
    - Limit query parameter. Limits number of results.
    type: int
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Configuration Templates GetTemplatesDetailsV2
  description: Complete reference of the GetTemplatesDetailsV2 API.
  link: https://developer.cisco.com/docs/dna-center/#!get-templates-details-v-2
notes:
  - SDK Method used are
    configuration_templates.ConfigurationTemplates.get_templates_details_v2,

  - Paths used are
    get /dna/intent/api/v2/template-programmer/template,

"""

EXAMPLES = r"""
- name: Get all Templates Details V2
  cisco.dnac.templates_details_v2_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    name: string
    projectId: string
    projectName: string
    softwareType: string
    softwareVersion: string
    productFamily: string
    productSeries: string
    productType: string
    filterConflictingTemplates: True
    tags: []
    unCommitted: True
    sortOrder: string
    allTemplateAttributes: True
    includeVersionDetails: True
    offset: 0
    limit: 0
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "author": "string",
      "composite": true,
      "containingTemplates": [
        {
          "composite": true,
          "description": "string",
          "deviceTypes": [
            {
              "productFamily": "string",
              "productSeries": "string",
              "productType": "string"
            }
          ],
          "id": "string",
          "language": "string",
          "name": "string",
          "projectName": "string",
          "rollbackTemplateParams": [
            {
              "binding": "string",
              "customOrder": 0,
              "dataType": "string",
              "defaultValue": "string",
              "description": "string",
              "displayName": "string",
              "group": "string",
              "id": "string",
              "instructionText": "string",
              "key": "string",
              "notParam": true,
              "order": 0,
              "paramArray": true,
              "parameterName": "string",
              "provider": "string",
              "range": [
                {
                  "id": "string",
                  "maxValue": 0,
                  "minValue": 0
                }
              ],
              "required": true,
              "selection": {
                "defaultSelectedValues": [
                  "string"
                ],
                "id": "string",
                "selectionType": "string",
                "selectionValues": {}
              }
            }
          ],
          "tags": [
            {
              "id": "string",
              "name": "string"
            }
          ],
          "templateContent": "string",
          "templateParams": [
            {
              "binding": "string",
              "customOrder": 0,
              "dataType": "string",
              "defaultValue": "string",
              "description": "string",
              "displayName": "string",
              "group": "string",
              "id": "string",
              "instructionText": "string",
              "key": "string",
              "notParam": true,
              "order": 0,
              "paramArray": true,
              "parameterName": "string",
              "provider": "string",
              "range": [
                {
                  "id": "string",
                  "maxValue": 0,
                  "minValue": 0
                }
              ],
              "required": true,
              "selection": {
                "defaultSelectedValues": [
                  "string"
                ],
                "id": "string",
                "selectionType": "string",
                "selectionValues": {}
              }
            }
          ],
          "version": "string"
        }
      ],
      "createTime": 0,
      "customParamsOrder": true,
      "description": "string",
      "deviceTypes": [
        {
          "productFamily": "string",
          "productSeries": "string",
          "productType": "string"
        }
      ],
      "failurePolicy": "string",
      "id": "string",
      "language": "string",
      "lastUpdateTime": 0,
      "latestVersionTime": 0,
      "name": "string",
      "parentTemplateId": "string",
      "projectAssociated": true,
      "projectId": "string",
      "projectName": "string",
      "rollbackTemplateContent": "string",
      "rollbackTemplateParams": [
        {
          "binding": "string",
          "customOrder": 0,
          "dataType": "string",
          "defaultValue": "string",
          "description": "string",
          "displayName": "string",
          "group": "string",
          "id": "string",
          "instructionText": "string",
          "key": "string",
          "notParam": true,
          "order": 0,
          "paramArray": true,
          "parameterName": "string",
          "provider": "string",
          "range": [
            {
              "id": "string",
              "maxValue": 0,
              "minValue": 0
            }
          ],
          "required": true,
          "selection": {
            "defaultSelectedValues": [
              "string"
            ],
            "id": "string",
            "selectionType": "string",
            "selectionValues": {}
          }
        }
      ],
      "softwareType": "string",
      "softwareVariant": "string",
      "softwareVersion": "string",
      "tags": [
        {
          "id": "string",
          "name": "string"
        }
      ],
      "templateContent": "string",
      "templateParams": [
        {
          "binding": "string",
          "customOrder": 0,
          "dataType": "string",
          "defaultValue": "string",
          "description": "string",
          "displayName": "string",
          "group": "string",
          "id": "string",
          "instructionText": "string",
          "key": "string",
          "notParam": true,
          "order": 0,
          "paramArray": true,
          "parameterName": "string",
          "provider": "string",
          "range": [
            {
              "id": "string",
              "maxValue": 0,
              "minValue": 0
            }
          ],
          "required": true,
          "selection": {
            "defaultSelectedValues": [
              "string"
            ],
            "id": "string",
            "selectionType": "string",
            "selectionValues": {}
          }
        }
      ],
      "validationErrors": {
        "rollbackTemplateErrors": {},
        "templateErrors": {},
        "templateId": "string",
        "templateVersion": "string"
      },
      "version": "string",
      "versionsInfo": [
        {
          "author": "string",
          "description": "string",
          "id": "string",
          "version": "string",
          "versionComment": "string",
          "versionTime": 0
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)


DOCUMENTATION = r"""
---
module: product_names_info
short_description: Information module for Product Names Info
description:
- This module represents an alias of the module product_names_v1_info
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  productName:
    description:
    - >
      ProductName query parameter. Filter with network device product name. Supports partial case-insensitive
      search. A minimum of 3 characters are required for search.
    type: str
  productId:
    description:
    - ProductId query parameter. Filter with product ID (PID).
    type: str
  offset:
    description:
    - >
      Offset query parameter. The first record to show for this page; the first record is numbered 1. The minimum
      value is 1.
    type: float
  limit:
    description:
    - >
      Limit query parameter. The number of records to show for this page. The minimum and maximum values are 1 and
      500, respectively.
    type: float
  productNameOrdinal:
    description:
    - ProductNameOrdinal path parameter. Product name ordinal is unique value for each network device product.
    type: float
requirements:
- dnacentersdk >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Software Image Management (SWIM) RetrieveNetworkDeviceProductNameV1
  description: Complete reference of the RetrieveNetworkDeviceProductNameV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!retrieve-network-device-product-name
- name: Cisco DNA Center documentation for Software Image Management (SWIM) RetrievesTheListOfNetworkDeviceProductNamesV1  # noqa: E501
  description: Complete reference of the RetrievesTheListOfNetworkDeviceProductNamesV1 API.
  link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-device-product-names
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.retrieve_network_device_product_name_v1,
    software_image_management_swim.SoftwareImageManagementSwim.retrieves_the_list_of_network_device_product_names_v1,

  - Paths used are
    get /dna/intent/api/v1/productNames,
    get /dna/intent/api/v1/productNames/{productNameOrdinal},
  - It should be noted that this module is an alias of product_names_v1_info

"""

EXAMPLES = r"""
- name: Get all Product Names Info
  cisco.dnac.product_names_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    productName: string
    productId: string
    offset: 0
    limit: 0
  register: result

- name: Get Product Names Info by name
  cisco.dnac.product_names_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    productNameOrdinal: 0
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "productName": "string",
        "productNameOrdinal": 0,
        "productIds": [
          "string"
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Ansible module to manage CheckPoint Firewall (c) 2019
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
#

from __future__ import (absolute_import, division, print_function)

__metaclass__ = type

ANSIBLE_METADATA = {'metadata_version': '1.1',
                    'status': ['preview'],
                    'supported_by': 'community'}

DOCUMENTATION = """
---
module: cp_mgmt_vsx_provisioning_tool
short_description: Run the VSX provisioning tool with the specified parameters.
description:
  - Run the VSX provisioning tool with the specified parameters. Note - An automatic session publish is part of all the operations in this API.
  - All operations are performed over Web Services API.
version_added: "6.0.0"
author: "Eden Brillant (@chkp-edenbr)"
options:
  operation:
    description:
      - The name of the provisioning operation to run. Each operation has its own specific parameters.<br> The available operations
        are,<ul><li><i>add-vsx-gateway</i> - Adds a new VSX gateway</li><li><i>add-vsx-cluster</i> - Adds a new VSX
        cluster*</li><li><i>add-vsx-cluster-member</i> - Adds a new VSX cluster member*</li><li><i>add-vd</i> - Adds a new Virtual Device (VS/VSB/VSW/VR) to a
        VSX gateway or VSX cluster</li><li><i>add-vd-interface</i> - Adds a new virtual interface to a Virtual Device</li><li><i>add-physical-interface</i> -
        Adds a physical interface to a VSX gateway or VSX cluster</li><li><i>add-route</i> - Adds a route to a Virtual Device</li><li><i>attach-bridge</i> -
        Attaches a bridge interface to a Virtual System</li><li><i>remove-vsx</i> - Removes a VSX gateway or VSX cluster</li><li><i>remove-vd</i> - Removes a
        Virtual Device</li><li><i>remove-vd-interface</i> - Removes an interface from a Virtual Device</li><li><i>remove-physical-interface</i> - Removes a
        physical interface from a VSX gateway or VSX cluster</li><li><i>remove-route</i> - Removes a route from a Virtual Device</li><li><i>set-vd</i> -
        Modifies a Virtual Device</li><li><i>set-vd-interface</i> - Modifies an interface on a Virtual Device</li><li><i>set-physical-interface</i> - Modifies
        a physical interface on a VSX cluster or VSX gateway</li></ul><br> * When adding a VSX Cluster, you must also add at least 2 cluster members<br> *
        Adding cluster members is only allowed when adding a new VSX cluster<br> * To add members to an existing cluster, use vsx-run-operation.
    type: str
    choices: ['attach-bridge', 'add-route', 'add-physical-interface', 'add-vd-interface', 'add-vsx-gateway', 'add-vsx-cluster', 'add-vd',
             'remove-route', 'remove-vd', 'remove-vsx', 'remove-physical-interface', 'remove-vd-interface', 'set-vd', 'set-physical-interface',
             'set-vd-interface']
  add_physical_interface_params:
    description:
      - Parameters for the operation to add a physical interface to a VSX gateway or VSX Cluster.
    type: dict
    suboptions:
      name:
        description:
          - Name of the interface.
        type: str
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
      vlan_trunk:
        description:
          - True if this interface is a VLAN trunk.
        type: bool
  add_route_params:
    description:
      - Parameters for the operation to add a route to a Virtual System or Virtual Router.
    type: dict
    suboptions:
      destination:
        description:
          - Route destination. To specify the default route, use 'default' for IPv4 and 'default6' for IPv6.
        type: str
      next_hop:
        description:
          - Next hop IP address.
        type: str
      leads_to:
        description:
          - Virtual Router for this route<br/>This VD must have an existing connection to the VR.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      netmask:
        description:
          - Subnet mask for this route.
        type: str
      prefix:
        description:
          - CIDR prefix for this route.
        type: str
      propagate:
        description:
          - Propagate this route to adjacent virtual devices.
        type: bool
  add_vd_interface_params:
    description:
      - Parameters for the operation to add a new interface to a Virtual Device.
    type: dict
    suboptions:
      leads_to:
        description:
          - Virtual Switch or Virtual Router for this interface.
        type: str
      name:
        description:
          - Name of the interface.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      anti_spoofing:
        description:
          - The anti-spoofing enforcement setting of this interface.
        type: str
        choices: ['prevent', 'detect', 'off']
      anti_spoofing_tracking:
        description:
          - The anti-spoofing tracking setting of this interface.
        type: str
        choices: ['none', 'alert', 'log']
      ipv4_address:
        description:
          - IPv4 Address of this interface with optional CIDR prefix.<br/>Required if this interface belongs to a Virtual System or Virtual Router.
        type: str
      ipv4_netmask:
        description:
          - IPv4 Subnet mask of this interface.
        type: str
      ipv4_prefix:
        description:
          - IPv4 CIDR prefix of this interface.
        type: str
      ipv6_address:
        description:
          - IPv6 Address of this interface<br/>Required if this interface belongs to a Virtual System or Virtual Router.
        type: str
      ipv6_netmask:
        description:
          - IPv6 Subnet mask of this interface.
        type: str
      ipv6_prefix:
        description:
          - IPv6 CIDR prefix of this interface.
        type: str
      mtu:
        description:
          - MTU of this interface.
        type: int
      propagate:
        description:
          - Propagate IPv4 route to adjacent virtual devices.
        type: bool
      propagate6:
        description:
          - Propagate IPv6 route to adjacent virtual devices.
        type: bool
      specific_group:
        description:
          - Specific group for interface topology.<br/>Only for use with topology option 'internal_specific'.
        type: str
      topology:
        description:
          - Topology of this interface.<br/>Automatic topology calculation based on routes must be disabled for this VS.
        type: str
        choices: ['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes']
      vti_settings:
        description:
          - VTI settings for this interface. This Virtual System must have VPN blade enabled.
        type: dict
        suboptions:
          local_ipv4_address:
            description:
              - The IPv4 address of the VPN tunnel on this Virtual System.
            type: str
          peer_name:
            description:
              - The name of the remote peer object as defined in the VPN community.
            type: str
          remote_ipv4_address:
            description:
              - The IPv4 address of the VPN tunnel on the remote VPN peer.
            type: str
          tunnel_id:
            description:
              - Optional unique Tunnel ID.<br/>Automatically assigned by the system if empty.
            type: str
  add_vd_params:
    description:
      - Parameters for the operation to add a new Virtual Device (VS/VSB/VSW/VR).
    type: dict
    suboptions:
      interfaces:
        description:
          - The list of interfaces for this new Virtual Device.<br/>Optional if this new VD is a Virtual Switch.
        type: list
        elements: dict
        suboptions:
          leads_to:
            description:
              - Virtual Switch or Virtual Router for this interface.
            type: str
          name:
            description:
              - Name of the interface.
            type: str
          anti_spoofing:
            description:
              - The anti-spoofing enforcement setting of this interface.
            type: str
            choices: ['prevent', 'detect', 'off']
          anti_spoofing_tracking:
            description:
              - The anti-spoofing tracking setting of this interface.
            type: str
            choices: ['none', 'alert', 'log']
          ipv4_address:
            description:
              - IPv4 Address of this interface with optional CIDR prefix.<br/>Required if this interface belongs to a Virtual System or Virtual Router.
            type: str
          ipv4_netmask:
            description:
              - IPv4 Subnet mask of this interface.
            type: str
          ipv4_prefix:
            description:
              - IPv4 CIDR prefix of this interface.
            type: str
          ipv6_address:
            description:
              - IPv6 Address of this interface<br/>Required if this interface belongs to a Virtual System or Virtual Router.
            type: str
          ipv6_netmask:
            description:
              - IPv6 Subnet mask of this interface.
            type: str
          ipv6_prefix:
            description:
              - IPv6 CIDR prefix of this interface.
            type: str
          mtu:
            description:
              - MTU of this interface.
            type: int
          propagate:
            description:
              - Propagate IPv4 route to adjacent virtual devices.
            type: bool
          propagate6:
            description:
              - Propagate IPv6 route to adjacent virtual devices.
            type: bool
          specific_group:
            description:
              - Specific group for interface topology.<br/>Only for use with topology option 'internal_specific'.
            type: str
          topology:
            description:
              - Topology of this interface.<br/>Automatic topology calculation based on routes must be disabled for this VS.
            type: str
            choices: ['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes']
      type:
        description:
          - Type of the Virtual Device <br><br>vs - Virtual Firewall<br>vr - Virtual Router<br>vsw - Virtual Switch<br>vsbm - Virtual Firewall in bridge mode.
        type: str
        choices: ['vs', 'vr', 'vsw', 'vsbm']
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
      calc_topology_auto:
        description:
          - Calculate interface topology automatically based on routes.<br/>Relevant only for Virtual Systems.<br/>Do not use for virtual devices.
        type: bool
      ipv4_address:
        description:
          - Main IPv4 Address.<br/>Required if this device is a Virtual System.<br/>Do not use for other virtual devices.
        type: str
      ipv4_instances:
        description:
          - Number of IPv4 instances for the Virtual System.<br/>Must be greater or equal to 1.<br/>Only relevant for Virtual Systems and Virtual
            Systems in bridge mode.
        type: int
      ipv6_address:
        description:
          - Main IPv6 Address.<br/>Required if this device is a Virtual System.<br/>Do not use for other virtual devices.
        type: str
      ipv6_instances:
        description:
          - Number of IPv6 instances for the Virtual System.<br/>Only relevant for Virtual Systems and Virtual Systems in bridge mode.
        type: int
      routes:
        description:
          - The list of routes for this new Virtual Device (VS or VR only).
        type: list
        elements: dict
        suboptions:
          destination:
            description:
              - Route destination. To specify the default route, use 'default' for IPv4 and 'default6' for IPv6.
            type: str
          next_hop:
            description:
              - Next hop IP address.
            type: str
          leads_to:
            description:
              - Virtual Router for this route<br/>This VD must have an existing connection to the VR.
            type: str
          netmask:
            description:
              - Subnet mask for this route.
            type: str
          prefix:
            description:
              - CIDR prefix for this route.
            type: str
          propagate:
            description:
              - Propagate this route to adjacent virtual devices.
            type: bool
      vs_mtu:
        description:
          - MTU of the Virtual System.<br/>Only relevant for Virtual Systems in bridge mode.<br/>Do not use for other virtual devices.
        type: int
  add_vsx_cluster_params:
    description:
      - Parameters for the operation to add a new VSX Cluster.
    type: dict
    suboptions:
      cluster_type:
        description:
          - Cluster type for the VSX Cluster Object.<br/>Starting in R81.10, only VSLS can be configured during cluster creation.<br/>To use High
            Availability ('ha'), first create the cluster as VSLS and then run vsx_util on the Management.
        type: str
        choices: ['vsls', 'ha']
      ipv4_address:
        description:
          - Main IPv4 Address of the VSX Gateway or Cluster object.<br/>Optional if main IPv6 Address is defined.
        type: str
      ipv6_address:
        description:
          - Main IPv6 Address of the VSX Gateway or Cluster object.<br/>Optional if main IPv4 Address is defined.
        type: str
      members:
        description:
          - The list of cluster members for this new VSX Cluster. Minimum, 2.
        type: list
        elements: dict
        suboptions:
          ipv4_address:
            description:
              - Main IPv4 Address of the VSX Cluster member.<br/>Mandatory if the VSX Cluster has an IPv4 Address.
            type: str
          ipv6_address:
            description:
              - Main IPv6 Address of the VSX Cluster member.<br/>Mandatory if the VSX Cluster has an IPv6 Address.
            type: str
          name:
            description:
              - Name of the new VSX Cluster member.
            type: str
          sic_otp:
            description:
              - SIC one-time-password of the VSX Gateway or Cluster member.<br/>Password must be between 4-127 characters in length.
            type: str
          sync_ip:
            description:
              - Sync IP address for the VSX Cluster member.
            type: str
      sync_if_name:
        description:
          - Sync interface name for the VSX Cluster.
        type: str
      sync_netmask:
        description:
          - Sync interface netmask for the VSX Cluster.
        type: str
      vsx_version:
        description:
          - Version of the VSX Gateway or Cluster object.
        type: str
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
      rule_drop:
        description:
          - Add a default drop rule to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_https:
        description:
          - Add a rule to allow HTTPS traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ping:
        description:
          - Add a rule to allow ping traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ping6:
        description:
          - Add a rule to allow ping6 traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_snmp:
        description:
          - Add a rule to allow SNMP traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ssh:
        description:
          - Add a rule to allow SSH traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
  add_vsx_gateway_params:
    description:
      - Parameters for the operation to add a new VSX Gateway.
    type: dict
    suboptions:
      ipv4_address:
        description:
          - Main IPv4 Address of the VSX Gateway or Cluster object.<br/>Optional if main IPv6 Address is defined.
        type: str
      ipv6_address:
        description:
          - Main IPv6 Address of the VSX Gateway or Cluster object.<br/>Optional if main IPv4 Address is defined.
        type: str
      sic_otp:
        description:
          - SIC one-time-password of the VSX Gateway or Cluster member.<br/>Password must be between 4-127 characters in length.
        type: str
      vsx_version:
        description:
          - Version of the VSX Gateway or Cluster object.
        type: str
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
      rule_drop:
        description:
          - Add a default drop rule to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_https:
        description:
          - Add a rule to allow HTTPS traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ping:
        description:
          - Add a rule to allow ping traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ping6:
        description:
          - Add a rule to allow ping6 traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_snmp:
        description:
          - Add a rule to allow SNMP traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
      rule_ssh:
        description:
          - Add a rule to allow SSH traffic to the VSX Gateway or Cluster initial policy.
        type: str
        choices: ['enable', 'disable']
  attach_bridge_params:
    description:
      - Parameters for the operation to attach a new bridge interface to a Virtual System.
    type: dict
    suboptions:
      ifs1:
        description:
          - Name of the first interface for the bridge.
        type: str
      ifs2:
        description:
          - Name of the second interface for the bridge.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
  remove_physical_interface_params:
    description:
      - Parameters for the operation to remove a physical interface from a VSX (Gateway or Cluster).
    type: dict
    suboptions:
      name:
        description:
          - Name of the interface.
        type: str
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
  remove_route_params:
    description:
      - Parameters for the operation to remove a route from a Virtual System or Virtual Router.
    type: dict
    suboptions:
      destination:
        description:
          - Route destination. To specify the default route, use 'default' for IPv4 and 'default6' for IPv6.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      netmask:
        description:
          - Subnet mask for this route.
        type: str
      prefix:
        description:
          - CIDR prefix for this route.
        type: str
  remove_vd_interface_params:
    description:
      - Parameters for the operation to remove a logical interface from a Virtual Device.
    type: dict
    suboptions:
      leads_to:
        description:
          - Virtual Switch or Virtual Router for this interface.
        type: str
      name:
        description:
          - Name of the interface.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
  remove_vd_params:
    description:
      - Parameters for the operation to remove a Virtual Device.
    type: dict
    suboptions:
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
  remove_vsx_params:
    description:
      - Parameters for the operation to remove a VSX Gateway or VSX Cluster.
    type: dict
    suboptions:
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
  set_physical_interface_params:
    description:
      - Parameters for the operation to change the configuration of a physical interface.
    type: dict
    suboptions:
      name:
        description:
          - Name of the interface.
        type: str
      vlan_trunk:
        description:
          - True if this interface is a VLAN trunk.
        type: bool
      vsx_name:
        description:
          - Name of the VSX Gateway or Cluster object.
        type: str
  set_vd_interface_params:
    description:
      - Parameters for the operation to change the configuration of a logical interface.
    type: dict
    suboptions:
      leads_to:
        description:
          - Virtual Switch or Virtual Router for this interface.
        type: str
      name:
        description:
          - Name of the interface.
        type: str
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      anti_spoofing:
        description:
          - The anti-spoofing enforcement setting of this interface.
        type: str
        choices: ['prevent', 'detect', 'off']
      anti_spoofing_tracking:
        description:
          - The anti-spoofing tracking setting of this interface.
        type: str
        choices: ['none', 'alert', 'log']
      ipv4_address:
        description:
          - IPv4 Address of this interface with optional CIDR prefix.<br/>Required if this interface belongs to a Virtual System or Virtual Router.
        type: str
      ipv6_address:
        description:
          - IPv6 Address of this interface<br/>Required if this interface belongs to a Virtual System or Virtual Router.
        type: str
      mtu:
        description:
          - MTU of this interface.
        type: int
      new_leads_to:
        description:
          - New Virtual Switch or Virtual Router for this interface.
        type: str
      propagate:
        description:
          - Propagate IPv4 route to adjacent virtual devices.
        type: bool
      propagate6:
        description:
          - Propagate IPv6 route to adjacent virtual devices.
        type: bool
      specific_group:
        description:
          - Specific group for interface topology.<br/>Only for use with topology option 'internal_specific'.
        type: str
      topology:
        description:
          - Topology of this interface.<br/>Automatic topology calculation based on routes must be disabled for this VS.
        type: str
        choices: ['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes']
  set_vd_params:
    description:
      - Parameters for the operation to change the configuration of a Virtual Device.
    type: dict
    suboptions:
      vd:
        description:
          - Name of the Virtual System, Virtual Switch, or Virtual Router.
        type: str
      calc_topology_auto:
        description:
          - Calculate interface topology automatically based on routes.<br/>Relevant only for Virtual Systems.<br/>Do not use for virtual devices.
        type: bool
      ipv4_address:
        description:
          - Main IPv4 Address.<br/>Relevant only if this device is a Virtual System.<br/>Do not use for other virtual devices.
        type: str
      ipv4_instances:
        description:
          - Number of IPv4 instances for the Virtual System.<br/>Must be greater or equal to 1.<br/>Only relevant for Virtual Systems and Virtual
            Systems in bridge mode.
        type: int
      ipv6_address:
        description:
          - Main IPv6 Address.<br/>Relevant only if this device is a Virtual System.<br/>Do not use for other virtual devices.
        type: str
      ipv6_instances:
        description:
          - Number of IPv6 instances for the Virtual System.<br/>Only relevant for Virtual Systems and Virtual Systems in bridge mode.
        type: int
      vs_mtu:
        description:
          - MTU of the Virtual System.<br/>Only relevant for Virtual Systems in bridge mode.<br/>Do not use for other virtual devices.
        type: int
extends_documentation_fragment: check_point.mgmt.checkpoint_commands
"""

EXAMPLES = """
- name: vsx-provisioning-tool
  cp_mgmt_vsx_provisioning_tool:
    add_vsx_cluster_params:
      cluster_type: vsls
      ipv4_address: 10.1.1.15
      members:
      - ipv4_address: 10.1.1.1
        name: VSX1
        sic_otp: sicotp123
        sync_ip: 192.168.1.1
      - ipv4_address: 10.1.1.2
        name: VSX2
        sic_otp: sicotp123
        sync_ip: 192.168.1.2
      rule_drop: enable
      rule_ping: enable
      sync_if_name: eth3
      sync_netmask: 255.255.255.0
      vsx_version: R81.10
      vsx_name: VSX_CLUSTER
    operation: add-vsx-cluster
"""

RETURN = """
cp_mgmt_vsx_provisioning_tool:
  description: The checkpoint vsx-provisioning-tool output.
  returned: always.
  type: dict
"""

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.check_point.mgmt.plugins.module_utils.checkpoint import checkpoint_argument_spec_for_commands, api_command


def main():
    argument_spec = dict(
        operation=dict(type='str', choices=['attach-bridge', 'add-route', 'add-physical-interface',
                                            'add-vd-interface', 'add-vsx-gateway', 'add-vsx-cluster', 'add-vd', 'remove-route', 'remove-vd', 'remove-vsx',
                                            'remove-physical-interface', 'remove-vd-interface', 'set-vd', 'set-physical-interface', 'set-vd-interface']),
        add_physical_interface_params=dict(type='dict', options=dict(
            name=dict(type='str'),
            vsx_name=dict(type='str'),
            vlan_trunk=dict(type='bool')
        )),
        add_route_params=dict(type='dict', options=dict(
            destination=dict(type='str'),
            next_hop=dict(type='str'),
            leads_to=dict(type='str'),
            vd=dict(type='str'),
            netmask=dict(type='str'),
            prefix=dict(type='str'),
            propagate=dict(type='bool')
        )),
        add_vd_interface_params=dict(type='dict', options=dict(
            leads_to=dict(type='str'),
            name=dict(type='str'),
            vd=dict(type='str'),
            anti_spoofing=dict(type='str', choices=['prevent', 'detect', 'off']),
            anti_spoofing_tracking=dict(type='str', choices=['none', 'alert', 'log']),
            ipv4_address=dict(type='str'),
            ipv4_netmask=dict(type='str'),
            ipv4_prefix=dict(type='str'),
            ipv6_address=dict(type='str'),
            ipv6_netmask=dict(type='str'),
            ipv6_prefix=dict(type='str'),
            mtu=dict(type='int'),
            propagate=dict(type='bool'),
            propagate6=dict(type='bool'),
            specific_group=dict(type='str'),
            topology=dict(type='str', choices=['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes']),
            vti_settings=dict(type='dict', options=dict(
                local_ipv4_address=dict(type='str'),
                peer_name=dict(type='str'),
                remote_ipv4_address=dict(type='str'),
                tunnel_id=dict(type='str')
            ))
        )),
        add_vd_params=dict(type='dict', options=dict(
            interfaces=dict(type='list', elements="dict", options=dict(
                leads_to=dict(type='str'),
                name=dict(type='str'),
                anti_spoofing=dict(type='str', choices=['prevent', 'detect', 'off']),
                anti_spoofing_tracking=dict(type='str', choices=['none', 'alert', 'log']),
                ipv4_address=dict(type='str'),
                ipv4_netmask=dict(type='str'),
                ipv4_prefix=dict(type='str'),
                ipv6_address=dict(type='str'),
                ipv6_netmask=dict(type='str'),
                ipv6_prefix=dict(type='str'),
                mtu=dict(type='int'),
                propagate=dict(type='bool'),
                propagate6=dict(type='bool'),
                specific_group=dict(type='str'),
                topology=dict(type='str', choices=['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes'])
            )),
            type=dict(type='str', choices=['vs', 'vr', 'vsw', 'vsbm']),
            vd=dict(type='str'),
            vsx_name=dict(type='str'),
            calc_topology_auto=dict(type='bool'),
            ipv4_address=dict(type='str'),
            ipv4_instances=dict(type='int'),
            ipv6_address=dict(type='str'),
            ipv6_instances=dict(type='int'),
            routes=dict(type='list', elements="dict", options=dict(
                destination=dict(type='str'),
                next_hop=dict(type='str'),
                leads_to=dict(type='str'),
                netmask=dict(type='str'),
                prefix=dict(type='str'),
                propagate=dict(type='bool')
            )),
            vs_mtu=dict(type='int')
        )),
        add_vsx_cluster_params=dict(type='dict', options=dict(
            cluster_type=dict(type='str', choices=['vsls', 'ha']),
            ipv4_address=dict(type='str'),
            ipv6_address=dict(type='str'),
            members=dict(type='list', elements="dict", options=dict(
                ipv4_address=dict(type='str'),
                ipv6_address=dict(type='str'),
                name=dict(type='str'),
                sic_otp=dict(type='str'),
                sync_ip=dict(type='str')
            )),
            sync_if_name=dict(type='str'),
            sync_netmask=dict(type='str'),
            vsx_version=dict(type='str'),
            vsx_name=dict(type='str'),
            rule_drop=dict(type='str', choices=['enable', 'disable']),
            rule_https=dict(type='str', choices=['enable', 'disable']),
            rule_ping=dict(type='str', choices=['enable', 'disable']),
            rule_ping6=dict(type='str', choices=['enable', 'disable']),
            rule_snmp=dict(type='str', choices=['enable', 'disable']),
            rule_ssh=dict(type='str', choices=['enable', 'disable'])
        )),
        add_vsx_gateway_params=dict(type='dict', options=dict(
            ipv4_address=dict(type='str'),
            ipv6_address=dict(type='str'),
            sic_otp=dict(type='str'),
            vsx_version=dict(type='str'),
            vsx_name=dict(type='str'),
            rule_drop=dict(type='str', choices=['enable', 'disable']),
            rule_https=dict(type='str', choices=['enable', 'disable']),
            rule_ping=dict(type='str', choices=['enable', 'disable']),
            rule_ping6=dict(type='str', choices=['enable', 'disable']),
            rule_snmp=dict(type='str', choices=['enable', 'disable']),
            rule_ssh=dict(type='str', choices=['enable', 'disable'])
        )),
        attach_bridge_params=dict(type='dict', options=dict(
            ifs1=dict(type='str'),
            ifs2=dict(type='str'),
            vd=dict(type='str')
        )),
        remove_physical_interface_params=dict(type='dict', options=dict(
            name=dict(type='str'),
            vsx_name=dict(type='str')
        )),
        remove_route_params=dict(type='dict', options=dict(
            destination=dict(type='str'),
            vd=dict(type='str'),
            netmask=dict(type='str'),
            prefix=dict(type='str')
        )),
        remove_vd_interface_params=dict(type='dict', options=dict(
            leads_to=dict(type='str'),
            name=dict(type='str'),
            vd=dict(type='str')
        )),
        remove_vd_params=dict(type='dict', options=dict(
            vd=dict(type='str')
        )),
        remove_vsx_params=dict(type='dict', options=dict(
            vsx_name=dict(type='str')
        )),
        set_physical_interface_params=dict(type='dict', options=dict(
            name=dict(type='str'),
            vlan_trunk=dict(type='bool'),
            vsx_name=dict(type='str')
        )),
        set_vd_interface_params=dict(type='dict', options=dict(
            leads_to=dict(type='str'),
            name=dict(type='str'),
            vd=dict(type='str'),
            anti_spoofing=dict(type='str', choices=['prevent', 'detect', 'off']),
            anti_spoofing_tracking=dict(type='str', choices=['none', 'alert', 'log']),
            ipv4_address=dict(type='str'),
            ipv6_address=dict(type='str'),
            mtu=dict(type='int'),
            new_leads_to=dict(type='str'),
            propagate=dict(type='bool'),
            propagate6=dict(type='bool'),
            specific_group=dict(type='str'),
            topology=dict(type='str', choices=['external', 'internal_undefined', 'internal_this_network', 'internal_specific', 'defined_by_routes'])
        )),
        set_vd_params=dict(type='dict', options=dict(
            vd=dict(type='str'),
            calc_topology_auto=dict(type='bool'),
            ipv4_address=dict(type='str'),
            ipv4_instances=dict(type='int'),
            ipv6_address=dict(type='str'),
            ipv6_instances=dict(type='int'),
            vs_mtu=dict(type='int')
        ))
    )
    argument_spec.update(checkpoint_argument_spec_for_commands)

    module = AnsibleModule(argument_spec=argument_spec)

    command = "vsx-provisioning-tool"

    result = api_command(module, command)
    module.exit_json(**result)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright: (c) 2018, Ripon Banik (@riponbanik)
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r'''
module: win_hostname
short_description: Manages local Windows computer name
description:
- Manages local Windows computer name.
- A reboot is required for the computer name to take effect.
options:
  name:
    description:
    - The hostname to set for the computer.
    type: str
    required: true
seealso:
- module: ansible.windows.win_dns_client
author:
- Ripon Banik (@riponbanik)
'''

EXAMPLES = r'''
- name: Change the hostname to sample-hostname
  ansible.windows.win_hostname:
    name: sample-hostname
  register: res

- name: Reboot
  ansible.windows.win_reboot:
  when: res.reboot_required
'''

RETURN = r'''
old_name:
  description: The original hostname that was set before it was changed.
  returned: always
  type: str
  sample: old_hostname
reboot_required:
  description: Whether a reboot is required to complete the hostname change.
  returned: always
  type: bool
  sample: true
'''
